@@ -1,6 +1,7 @@
 #!/usr/bin/env python
 # coding: utf-8
-# Only pyfontain developers should use this file to update files
+# Only pyfontaine developers should use this file to update files
+import logging
 import os
 import os.path as op
 import requests
@@ -10,8 +11,25 @@ import shutil
 APPDATA_DIRNAME = 'pyfontaine'
 
 
+def get_data_directory():
+    try:
+        #Windows code:
+        d = op.join(os.environ["APPDATA"], APPDATA_DIRNAME)
+    except KeyError:
+        #Linux and Mac code:
+        d = op.join(op.expanduser("~"), ".local", "share", APPDATA_DIRNAME)
+    if not op.exists(d):
+        os.makedirs(d)
+    return d
+
+
 def get_file(name, url):
-    r = requests.get(url)
+    try:
+        r = requests.get(url)
+    except requests.exceptions.RequestException:
+        logging.warn(('Please run pyfontaine with an active internet '
+                      'connection to download all character maps'))
+        return False
     if r.status_code == 200:
         with open(name, 'w') as f:
             f.write(r.content)
@@ -19,17 +37,11 @@ def get_file(name, url):
 
 
 def get_from_cache(filename, url):
-    try:
-        #Windows code:
-        directory = op.join(os.environ["APPDATA"], APPDATA_DIRNAME)
-    except KeyError:
-        #Linux and Mac code:
-        directory = op.join(op.expanduser("~"), ".local", "share", APPDATA_DIRNAME)
-    if not op.exists(directory):
-        os.makedirs(directory)
+    directory = get_data_directory()
     filepath = op.join(directory, filename)
     if not op.exists(filepath) and not get_file(filepath, url):
-        shutil.copy(op.join(os.path.dirname(__file__), filename), filepath)
+        shutil.copy(op.join(os.path.dirname(__file__), 'data', filename),
+                    filepath)
     return filepath
 
 
